@@ -1,9 +1,12 @@
 import logging
 
+from django.contrib.admin.models import ADDITION
 from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django_filters.rest_framework import DjangoFilterBackend
 
+from cms.contexts.utils import log_obj_event
+
 from rest_framework import generics
 from rest_framework import filters
 from rest_framework.exceptions import PermissionDenied
@@ -25,9 +28,19 @@ class UniCMSListCreateAPIView(generics.ListCreateAPIView):
     filter_backends = [filters.SearchFilter,
                        DjangoFilterBackend,
                        filters.OrderingFilter]
-    filterset_fields = ['is_active', 'created', 'modified']
+    filterset_fields = ['is_active', 'created', 'modified', 'created_by']
     pagination_class = UniCmsApiPagination
 
+    def post(self, request, *args, **kwargs):
+        post_request = super().post(request, *args, **kwargs)
+        model_class = self.serializer_class.Meta.model
+        item = model_class.objects.filter(pk=post_request.data['id']).first()
+        log_obj_event(user=request.user,
+                      obj=item,
+                      data=request.data,
+                      action_flag=ADDITION)
+        return post_request
+
     class Meta:
         abstract = True
 
@@ -52,13 +65,21 @@ class UniCMSCachedRetrieveUpdateDestroyAPIView(generics.RetrieveUpdateDestroyAPI
 
     def patch(self, request, *args, **kwargs):
         item = self.get_queryset().first()
+        # check for locks
         check_locks(item, request.user)
-        return super().patch(request, *args, **kwargs)
+        ok_response = super().patch(request, *args, **kwargs)
+        # log action in item history
+        log_obj_event(user=request.user, obj=item, data=request.data)
+        return ok_response
 
     def put(self, request, *args, **kwargs):
         item = self.get_queryset().first()
+        # check for locks
         check_locks(item, request.user)
-        return super().put(request, *args, **kwargs)
+        ok_response = super().put(request, *args, **kwargs)
+        # log action in item history
+        log_obj_event(user=request.user, obj=item, data=request.data)
+        return ok_response
 
     def delete(self, request, *args, **kwargs):
         item = self.get_queryset().first()
