@@ -114,8 +114,8 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
             return self.url
         elif self.webpath:
             if self.publication:
-                webpath = self.publication.get_publication_context(webpath=self.webpath)
-                return webpath.url
+                ctx_webpath = self.publication.get_publication_context(webpath=self.webpath)
+                return ctx_webpath.url if ctx_webpath else ''
             else:
                 return self.webpath.get_full_path()
         else: # pragma: no cover
